@@ -6,12 +6,12 @@ use warnings;
 
 package Test::BrewBuild::Plugin::TestAgainst;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 my $state = bless {}, __PACKAGE__;
 
 sub brewbuild_exec{
-    shift;
+    shift; # throw away class
     my $log = shift;
     my $module = shift;
     return _cmd($module);
